function obj = gallery(varargin)

  obj = 0;
  switch lower(varargin{1})
   case 'constant'
    p = varargin{2};
    obj = rkfun(zeros(1, 0), zeros(1, 0), p(1));     
     
   case 'cheby'
    if nargin < 2, n = 5; else n = varargin{2}; end
    e = .5*ones(n,1); e(1) = 1;     
    H = full(spdiags([e,0*e,e],-1:1,n+1,n));    
    K = eye(n+1,n); 
    c = zeros(n+1,1); 
    c(n+1) = 1;
    obj = rkfun(K, H, c, n);
    
   case 'cayley'
    obj = nodes2rkfun(1,-1,-1);
    
   case 'moebius'
    p = varargin{2};
    obj = rkfun([-p(1) ; p(3)], [p(2) ; -p(4)], [0;1]);
    
   case 'sqrt'
    % Zolotarev's sqrt approximation on [1, b] of type (d, d-1).         
    if nargin < 2, d = 8;   else d = varargin{2};       end
    if nargin < 3, b = 1e2; else b = sqrt(varargin{3}); end
    d  = max(d, 1); 
    b  = max(b, 2);
    k  = sqrt(2)/b; 
    ks = sqrt(1-k^2); 
    Ks = ellipke(ks);
    ell= 1:2*d-1;
    c  = ellipj(ell*Ks/(2*d),ks).^2; 
    c  = c./(1-c);
    zero = -c(2:2:end); 
    pole = -c(1:2:end);
    % Determine scaling factor D.
    [sn, cn, dn] = ellipj((1:2*d).*Ks./(2*d), ks);
    extrema = [1 dn.^-2];
    r = 1;
    for ell = 1:d
      if ell < d
        r = r.*(extrema-zero(ell))./(extrema-pole(ell));        
      else        
        r = r./(extrema-pole(ell));
      end
    end
    D   = sqrt(max(sqrt(extrema).*r)*min(sqrt(extrema).*r));
    obj = nodes2rkfun(pole, zero, D);
    
   case 'sign'
    % Zolotarev's sign approximation on +/-[1, b] 
    % of type (2*d-1, 2*d).    
    if nargin < 2, d = 8;   else d = varargin{2}; end
    if nargin < 3, b = 1e4; else b = varargin{3}; end
    d  = max(d, 1); 
    b  = max(b, 1.5);
    k  = sqrt(2)/b; 
    ks = sqrt(1-k^2); 
    Ks = ellipke(ks);
    ell= 1:2*d-1;
    c  = ellipj(ell*Ks/(2*d),ks).^2; 
    c  = c./(1-c);
    zero = -c(2:2:end); 
    pole = -c(1:2:end);
    % Determine scaling factor D.
    [sn, cn, dn] = ellipj((1:2*d).*Ks./(2*d), ks);
    extrema = [1 dn.^-2];
    r = 1;
    for ell = 1:d
      if ell < d
        r = r.*(extrema-zero(ell))./(extrema-pole(ell));
      else
        r = r./(extrema-pole(ell));
      end
    end
    D = sqrt(max(sqrt(extrema).*r)*min(sqrt(extrema).*r));
    % r = r/D; is now relative approximation to 1/sqrt(x)
    % now use sign(x) = x/sqrt(x^2)
    rts(1:2:2*(d-1)) = +sqrt(zero);
    rts(2:2:2*(d-1)) = -sqrt(zero);
    pls(1:2:2*d) = +sqrt(pole);
    pls(2:2:2*d) = -sqrt(pole);
    rts(2*d-1) = 0;
    scl = 1/D;
    obj = nodes2rkfun(rts, pls, scl);
    
    case 'step'
     if nargin < 2, d = 8;   else d = varargin{2}; end
     if nargin < 3, b = 1e4; else b = varargin{3}; end
     d = max(d, 1); 
     b = max(b, 1.5);
     % Zolotarev's sign approximation on [1, b] of 
     % type (2*d-1, 2*d).
     r = gallery('sign', d, b);
     % Compose with Moebius transform.
     m = -sqrt(b)*gallery('moebius',[1, 1, 1, -1]); 
     obj = 0.5*feval(r, m) + 0.5;
			
   otherwise 
    obj = sym2rkfun(varargin{1});    
  end
        
end % function gallery
